@@ -100,6 +100,11 @@ auto.arima <- function(y, d=NA, D=NA, max.p=5, max.q=5,
     warning("Parallel computer is only implemented when stepwise=FALSE, the model will be fit in serial.")
     parallel <- FALSE
   }
+  
+  if (trace && parallel) {
+    message("Tracing model searching in parallel is not supported.")
+    trace <- FALSE
+  }
 
   series <- deparse(substitute(y))
   x <- as.ts(x)
@@ -319,7 +324,11 @@ auto.arima <- function(y, d=NA, D=NA, max.p=5, max.q=5,
   allowmean <- allowmean & (d + D) == 0
 
   constant <- allowdrift | allowmean
-
+  
+  if (approximation && trace) {
+    cat("\n Fitting models using approximations to speed things up...\n")
+  }
+  
   if (!stepwise) {
     bestfit <- search.arima(
       x, d, D, max.p, max.q, max.P, max.Q, max.order, stationary,
@@ -333,6 +342,9 @@ auto.arima <- function(y, d=NA, D=NA, max.p=5, max.q=5,
     bestfit$x <- orig.x
     bestfit$series <- series
     bestfit$fitted <- fitted(bestfit)
+    if (trace) {
+      cat("\n\n Best model:", arima.string(bestfit, padding = TRUE), "\n\n")
+    }
     return(bestfit)
   }
 
@@ -350,10 +362,6 @@ auto.arima <- function(y, d=NA, D=NA, max.p=5, max.q=5,
 
   results <- matrix(NA, nrow = 100, ncol = 8)
 
-  if (approximation && trace) {
-    cat("\n Fitting models using approximations to speed things up...\n")
-  }
-
   bestfit <- myarima(x, order = c(p, d, q), seasonal = c(P, D, Q), constant = constant, ic, trace, approximation, offset = offset, xreg = xreg, ...)
   results[1, ] <- c(p, d, q, P, D, Q, constant, bestfit$ic)
   # Null model with possible constant
@@ -771,5 +779,5 @@ checkarima <- function(object) {
 is.constant <- function(x) {
   x <- as.numeric(x)
   y <- rep(x[1], length(x))
-  return(identical(x, y))
+  return(isTRUE(all.equal(x, y)))
 }
