@@ -13,6 +13,8 @@
 #' variables, the errors will be identical to the original series (possibly
 #' adjusted to have zero mean).  \code{arima.errors} is a deprecated function
 #' which is identical to \code{residuals.Arima(object, type="regression")}.
+#' For \code{nnetar} objects, when \code{type="innovations"} and \code{lambda} is used, a
+#' matrix of time-series consisting of the residuals from each of the fitted neural networks is returned.
 #'
 #' @param object An object containing a time series model of class \code{ar},
 #' \code{Arima}, \code{bats}, \code{ets}, \code{fracdiff}, \code{nnetar} or
@@ -24,25 +26,24 @@
 #' @param h If \code{type='response'}, then the fitted values are computed for
 #' \code{h}-step forecasts.
 #' @param ... Other arguments not used.
-#' @return A \code{ts} object
+#' @return A \code{ts} object.
 #' @author Rob J Hyndman
 #' @seealso \code{\link{fitted.Arima}}, \code{\link{checkresiduals}}.
 #' @keywords ts
 #'
 #' @export
-residuals.forecast <- function(object, type=c("innovation","response"), ...)
-{
+residuals.forecast <- function(object, type=c("innovation", "response"), ...) {
   type <- match.arg(type)
-  if(type=="innovation")
+  if (type == "innovation") {
     object$residuals
-  else
+  } else {
     getResponse(object) - fitted(object)
+  }
 }
 
 #' @rdname residuals.forecast
 #' @export
-residuals.ar <- function(object, type=c("innovation","response"),...)
-{
+residuals.ar <- function(object, type=c("innovation", "response"), ...) {
   type <- match.arg(type)
   # innovation and response residuals are the same for AR models
   object$resid
@@ -56,121 +57,128 @@ residuals.ar <- function(object, type=c("innovation","response"),...)
 #' plot(residuals(fit))
 #' plot(residuals(fit, type='response'))
 #' @export
-residuals.Arima <- function(object, type=c("innovation","response","regression"), h=1, ...)
-{
+residuals.Arima <- function(object, type=c("innovation", "response", "regression"), h=1, ...) {
   type <- match.arg(type)
-  if(type=="innovation")
+  if (type == "innovation") {
     object$residuals
-  else if(type=="response")
-    getResponse(object) - fitted(object, h=h)
-  else
-  {
+  } else if (type == "response") {
+    getResponse(object) - fitted(object, h = h)
+  } else {
     x <- getResponse(object)
-    if(!is.null(object$lambda))
-      x <- BoxCox(x,object$lambda)
+    if (!is.null(object$lambda)) {
+      x <- BoxCox(x, object$lambda)
+    }
     xreg <- getxreg(object)
     # Remove intercept
-    if(is.element("intercept",names(object$coef)))
-      xreg <- cbind(rep(1,length(x)),xreg)
+    if (is.element("intercept", names(object$coef))) {
+      xreg <- cbind(rep(1, length(x)), xreg)
+    }
     # Return errors
-    if(is.null(xreg))
+    if (is.null(xreg)) {
       return(x)
-    else
-    {
+    } else {
       norder <- sum(object$arma[1:4])
-      return(ts(c(x - xreg %*% as.matrix(object$coef[(norder+1):length(object$coef)])),
-        frequency=frequency(x),start=start(x)))
+      return(ts(
+        c(x - xreg %*% as.matrix(object$coef[(norder + 1):length(object$coef)])),
+        frequency = frequency(x), start = start(x)
+      ))
     }
   }
 }
 
 #' @rdname residuals.forecast
 #' @export
-residuals.bats <- function(object, type=c("innovation","response"), h=1, ...)
-{
+residuals.bats <- function(object, type=c("innovation", "response"), h=1, ...) {
   type <- match.arg(type)
-  if(type=="innovation")
+  if (type == "innovation") {
     object$errors
-  else
-    getResponse(object) - fitted(object, h=h)
+  } else {
+    getResponse(object) - fitted(object, h = h)
+  }
 }
 
 #' @rdname residuals.forecast
 #' @export
-residuals.tbats <- function(object, type=c("innovation","response"), h=1, ...)
-{
+residuals.tbats <- function(object, type=c("innovation", "response"), h=1, ...) {
   type <- match.arg(type)
-  if(type=="innovation")
+  if (type == "innovation") {
     object$errors
-  else
-    getResponse(object) - fitted(object, h=h)
+  } else {
+    getResponse(object) - fitted(object, h = h)
+  }
 }
 
 #' @rdname residuals.forecast
 #' @export
-residuals.ets <- function(object, type=c("innovation","response"), h=1, ...)
-{
+residuals.ets <- function(object, type=c("innovation", "response"), h=1, ...) {
   type <- match.arg(type)
-  if(type=="innovation")
+  if (type == "innovation") {
     object$residuals
-  else
-    getResponse(object) - fitted(object, h=h)
+  } else {
+    getResponse(object) - fitted(object, h = h)
+  }
 }
 
 #' @rdname residuals.forecast
 #' @export
-residuals.fracdiff <- function(object, type=c("innovation","response"), ...)
-{
+residuals.fracdiff <- function(object, type=c("innovation", "response"), ...) {
   type <- match.arg(type)
-  if(type=="innovation")
-  {
-    if(!is.null(object$residuals))   # Object produced by arfima()
+  if (type == "innovation") {
+    if (!is.null(object$residuals)) { # Object produced by arfima()
       return(object$residuals)
-    else                             # Object produced by fracdiff()
+    } else # Object produced by fracdiff()
     {
-      if (is.element("x", names(object)))
+      if (is.element("x", names(object))) {
         x <- object$x
-      else
-        x <- eval.parent(parse(text=as.character(object$call)[2]))
-      if(!is.null(object$lambda))
-        x <- BoxCox(x,object$lambda)
-      y <- fracdiff::diffseries(x - mean(x), d=object$d)
-      fit <- arima(y, order=c(length(object$ar),0,length(object$ma)), include.mean=FALSE, fixed=c(object$ar,-object$ma))
-      return(residuals(fit, type="innovation"))
+      } else {
+        x <- eval.parent(parse(text = as.character(object$call)[2]))
+      }
+      if (!is.null(object$lambda)) {
+        x <- BoxCox(x, object$lambda)
+      }
+      y <- fracdiff::diffseries(x - mean(x), d = object$d)
+      fit <- arima(y, order = c(length(object$ar), 0, length(object$ma)), include.mean = FALSE, fixed = c(object$ar, -object$ma))
+      return(residuals(fit, type = "innovation"))
     }
   }
-  else
+  else {
     getResponse(object) - fitted(object)
+  }
 }
 
 #' @rdname residuals.forecast
 #' @export
-residuals.nnetar <- function(object, type=c("innovation","response"), h=1, ...)
-{
+residuals.nnetar <- function(object, type=c("innovation", "response"), h=1, ...) {
   type <- match.arg(type)
-  if(type=="innovation" & !is.null(object$lambda))
-  {
-    res <- matrix(unlist(lapply(object$model, residuals)), ncol=length(object$model))
-    if(!is.null(object$scalex$scale))
+  if (type == "innovation" && !is.null(object$lambda)) {
+    res <- matrix(unlist(lapply(object$model, residuals)), ncol = length(object$model))
+    if (!is.null(object$scalex$scale)) {
       res <- res * object$scalex$scale
+    }
+  }
+  else {
+    res <- getResponse(object) - fitted(object, h = h)
   }
-  else
-    res <- getResponse(object) - fitted(object, h=h)
 
   tspx <- tsp(getResponse(object))
-  res <- ts(res, frequency=tspx[3L], end=tspx[2L])
+  res <- ts(res, frequency = tspx[3L], end = tspx[2L])
 
   return(res)
 }
 
 #' @rdname residuals.forecast
 #' @export
-residuals.stlm <- function(object, type=c("innovation","response"), ...)
-{
+residuals.stlm <- function(object, type=c("innovation", "response"), ...) {
   type <- match.arg(type)
-  if(type=="innovation")
+  if (type == "innovation") {
     object$residuals
-  else
+  } else {
     getResponse(object) - fitted(object)
+  }
 }
 
+#' @rdname residuals.forecast
+#' @export
+residuals.tslm <- function(object, ...) {
+  object$residuals
+}
