@@ -27,9 +27,40 @@ if (require(testthat)) {
           iextracted <- fitarima$arma[6]
           maextracted <- fitarima$arma[2]
           expect_true(all(arimaorder(fitarima) == c(arextracted, iextracted, maextracted)))
+          expect_true(all(names(arimaorder(fitarima)) == c("p", "d", "q")))
+          expect_true(arimaorder(fitarima)["p"] == ar)
+          expect_true(arimaorder(fitarima)["d"] == i)
+          expect_true(arimaorder(fitarima)["q"] == ma)
         }
       }
     }
+
+    # Test ar
+    arMod <- ar(lynx, order.max = 2)
+    expect_true(arimaorder(arMod)["p"] == 2)
+    expect_true(arimaorder(arMod)["d"] == 0)
+    expect_true(arimaorder(arMod)["q"] == 0)
+    expect_true(all(names(arimaorder(arMod)) == c("p", "d", "q")))
+
+    # Test SARIMA
+    sarimaMod <- Arima(wineind, order = c(1, 1, 2), seasonal=c(0, 1,1))
+    expect_true(all(names(arimaorder(sarimaMod)) == c("p", "d", "q", "P", "D", "Q", "Frequency")))
+    expect_true(arimaorder(sarimaMod)["p"] == 1)
+    expect_true(arimaorder(sarimaMod)["d"] == 1)
+    expect_true(arimaorder(sarimaMod)["q"] == 2)
+    expect_true(arimaorder(sarimaMod)["P"] == 0)
+    expect_true(arimaorder(sarimaMod)["D"] == 1)
+    expect_true(arimaorder(sarimaMod)["Q"] == 1)
+    expect_true(arimaorder(sarimaMod)["Frequency"] == frequency(wineind))
+
+    # Test fracdiff
+    set.seed(4)
+    fracdiffMod <- fracdiff::fracdiff(lynx, nar = 2, nma = 2)
+    expect_true(all(names(arimaorder(fracdiffMod)) == c("p", "d", "q")))
+    expect_true(arimaorder(fracdiffMod)["p"] == 2)
+    expect_true(arimaorder(fracdiffMod)["d"] >= 0)
+    expect_true(arimaorder(fracdiffMod)["d"] <= 1)
+    expect_true(arimaorder(fracdiffMod)["p"] == 2)
   })
 
   test_that("tests for forecast.Arima", {
