@@ -108,5 +108,23 @@ if (require(testthat)) {
     expect_true(identical(which(!is.na(fitted(oilnnet))), 11:20))
     oilnnet <- nnetar(airmiles, subset = c(rep(F, 10), rep(T, 10), rep(F, length(airmiles) - 20)))
     expect_true(identical(which(!is.na(fitted(oilnnet))), 11:20))
+    ## Check short and constant data
+    expect_warning(nnetfit <- nnetar(rep(1, 10), p=2, P=0, size=1, repeats=1, lambda = 0.1), "Constant data")
+    expect_true(nnetfit$p == 1)
+    expect_true(is.null(nnetfit$lambda))
+    expect_true(is.null(nnetfit$scalex))
+    expect_error(nnetfit <- nnetar(rnorm(2), p=1, P=0, size=1, repeats=1), "Not enough data")
+    expect_silent(nnetfit <- nnetar(rnorm(3), p=1, P=0, size=1, repeats=1))
+    expect_true(nnetfit$p == 1)
+    expect_silent(nnetfit <- nnetar(rnorm(3), p=2, P=0, size=1, repeats=1))
+    expect_true(nnetfit$p == 2)
+    expect_warning(nnetfit <- nnetar(rnorm(3), p=3, P=0, size=1, repeats=1), "short series")
+    expect_true(nnetfit$p == 2)
+    expect_warning(nnetfit <- nnetar(rnorm(3), p=4, P=0, size=1, repeats=1), "short series")
+    expect_true(nnetfit$p == 2)
+    expect_warning(nnetfit <- nnetar(rnorm(10), xreg=rep(1, 10), p=2, P=0, size=1, repeats=1, lambda = 0.1), "Constant xreg")
+    expect_true(is.null(nnetfit$scalexreg))
+    expect_warning(nnetfit <- nnetar(rnorm(3), xreg=matrix(c(1, 2, 3, 1, 1, 1), ncol=2), p=1, P=0, size=1, repeats=1, lambda = 0.1), "Constant xreg")
+    expect_true(is.null(nnetfit$scalexreg))
   })
 }
